@@ -24,23 +24,24 @@
 
 /* 
 
-    Checks if...
-    ...the theme has been changed; if so, check if it is necessary to change the special font colors.
-    ...the font size has been changed; if so, changes the size of icons and/or readjusts the tab stops 
-    of the hints window according to the new font size. Also changes the font size of the Enter Values 
-    label.
-    ...a valid icon file path has become invalid; if so, changes the icon to a broken one.
-    ...an invalid icon file path has become valid; if so, replaces the broken icon with the icon image,
-    if it is a proper image file.
+    Checks for the following changes:
+
+    - Theme changes: If the theme has changed, determine whether special font colors need to be updated.
+    - Font size changes: If the font size has changed, update icon sizes and/or readjust the tab stops
+      in the hints window accordingly. Also update the font size of the “Enter Values” label.
+    - Icon path validity changes:
+      * If a previously valid icon file path becomes invalid, replace the icon with a “broken” icon.
+      * If a previously invalid icon file path becomes valid and points to a proper image file, replace
+        the broken icon with the actual image.
 
 */
 
-// The identifier is not used by the function, but to switch the timeout on and off.
+// The identifier is not used by the function itself but is used to toggle the timeout on and off.
 gboolean check_for_external_file_and_settings_changes (G_GNUC_UNUSED gpointer identifier)
 {
     g_autofree gchar *font_desc;
-    gboolean font_size_has_changed = FALSE; // Default
-    gboolean create_new_invalid_icon_imgs = FALSE; // Default
+    gboolean font_size_has_changed = FALSE; // Default value.
+    gboolean create_new_invalid_icon_imgs = FALSE; // Default value.
 
     determine_theme_type ();
 
@@ -51,7 +52,7 @@ gboolean check_for_external_file_and_settings_changes (G_GNUC_UNUSED gpointer id
 
         FREE_AND_REASSIGN (ks.font_desc, g_strdup (font_desc));
 
-        // Check if font size has changed.
+        // Check if the font size has changed.
         if ((font_size_has_changed = (G_UNLIKELY (ks.font_size != (font_size_updated = get_font_size ()))))) {
             ks.font_size = font_size_updated;
 
@@ -96,9 +97,9 @@ gboolean check_for_external_file_and_settings_changes (G_GNUC_UNUSED gpointer id
             create_new_invalid_icon_imgs = TRUE;
         }
 
-        /* If font size or icon theme has changed, recreate the invalid icon images.
-           create_new_invalid_icon_imgs was already set to TRUE if the font size was changed, 
-           so this separate if statement is set to act upon both a font size and icon theme change. */
+        /* If the font size or icon theme has changed, recreate the “invalid” icon images.
+           create_new_invalid_icon_imgs is already set to TRUE if the font size has changed,
+           so this check applies when either the font size or the icon theme has changed. */
         if (G_UNLIKELY (create_new_invalid_icon_imgs)) {
             create_invalid_icon_imgs ();
         }
@@ -109,7 +110,7 @@ gboolean check_for_external_file_and_settings_changes (G_GNUC_UNUSED gpointer id
             g_autofree gchar *icon_modification_time_txt_loop, 
                              *icon_path_txt_loop;
             guint icon_img_status_uint_loop;
-            gboolean replacement_done = FALSE; // Default
+            gboolean replacement_done = FALSE; // Default value.
 
             gtk_tree_model_get_iter (ks.ts_model, &iter_loop, path_loop);
 
@@ -122,9 +123,9 @@ gboolean check_for_external_file_and_settings_changes (G_GNUC_UNUSED gpointer id
             g_autoptr(GFile) icon_loop = g_file_new_for_path (icon_path_txt_loop);
 
             /*
-                Case 1: Stored path no longer points to a valid icon image, so icon has to replaced with broken icon.
-                Case 2: Invalid path to an icon image has become valid.
-                Case 3: Icon image file is replaced with another one.
+                Case 1: The stored path no longer points to a valid icon image — replace it with a “broken” icon.
+                Case 2: A previously invalid icon path has become valid.
+                Case 3: The icon image file has been replaced with a different file.
             */
             if (G_LIKELY (icon_img_status_uint_loop != INVALID_PATH) && 
                 G_UNLIKELY (!(g_file_query_exists (icon_loop, NULL)))) { // Case 1
@@ -145,7 +146,7 @@ gboolean check_for_external_file_and_settings_changes (G_GNUC_UNUSED gpointer id
 
                 if (G_UNLIKELY (icon_img_status_uint_loop == INVALID_PATH ||
                                 !STREQ (time_stamp, icon_modification_time_txt_loop))) {
-                    // Case 2 & 3, FALSE 1 = don't show error message when error occurs, FALSE 2 = not during undo/redo
+                    // Cases 2 & 3: FALSE 1 = do not show an error message on failure, FALSE 2 = not during undo/redo
                     if (G_UNLIKELY (!(set_icon (&iter_loop, icon_path_txt_loop, FALSE, FALSE)))) { 
                         gtk_tree_store_set (ks.treestore, &iter_loop, 
                                             TS_ICON_IMG, ks.invalid_icon_imgs[INVALID_FILE_ICON], 
@@ -164,22 +165,22 @@ gboolean check_for_external_file_and_settings_changes (G_GNUC_UNUSED gpointer id
             }
 
             /*
-                If the font size or icon theme has changed, replace the icon images accordingly,
-                but only if the icons have not been replaced already, since the replacement icons already have the new size.
+                If the font size or icon theme has changed, update the icon images accordingly.
+                Skip this if the icons were already replaced above, since they already match the new size.
             */
             if (G_UNLIKELY (!replacement_done && 
                             (font_size_has_changed || (create_new_invalid_icon_imgs && icon_img_status_uint_loop)))) {
                 if (!icon_img_status_uint_loop) { // Icon path is OK and valid icon exists -> create and store larger or smaller icon
-                    // FALSE 1 = don't show error message when error occurs, FALSE 2 = not during undo/redo
+                    // FALSE 1 = do not show an error message on failure, FALSE 2 = not during undo/redo
                     set_icon (&iter_loop, icon_path_txt_loop, FALSE, FALSE);
                 }
-                else { // Icon path is wrong or icon image is invalid = store broken icon with larger or smaller size
+                else { // Icon path is invalid or icon file is invalid → store “broken” icon in new size
                     gtk_tree_store_set (ks.treestore, &iter_loop, TS_ICON_IMG, 
                                         ks.invalid_icon_imgs[(icon_img_status_uint_loop == INVALID_PATH) ? 
                                                              INVALID_PATH_ICON : INVALID_FILE_ICON], -1);
                 }
 
-                gtk_tree_view_columns_autosize (GTK_TREE_VIEW (ks.treeview)); // In case that the font size has been reduced.
+                gtk_tree_view_columns_autosize (GTK_TREE_VIEW (ks.treeview)); // Adjust in case the font size decreased.
             }
         }
     }
@@ -209,7 +210,7 @@ gboolean check_for_external_file_and_settings_changes (G_GNUC_UNUSED gpointer id
 
 /* 
 
-    Stops the timer and erases the list of icon occourrences.
+    Stops the timer and clears the list of icon occurrences.
 
 */
 
