@@ -39,16 +39,17 @@ def main():
     
     # List of English sentences to be replaced
     english_sentences = [
-        "<big>K</big>ickshaw accepts the following XML elements and attribute names, attribute values, and contents associated with these elements:",
+        "<big>K</big>ickshaw accepts the following XML elements, attribute names, attribute values, and contents associated with these elements:",
         "Element",
         "Attribute Names",
         "Attribute Values",
         "Contents",
-        "Menu IDs consisting of empty strings are valid, but like any other menu ID can only appear once in a menu.",
-        "The following menus are equivalent and both accepted by Openbox and Kickshaw.",
-        "A menu is always shown inside Kickshaw as it would appear in Openbox, so the latter of the two examples is closer to a WYSIWYG approach. The downside is that for large menus, this can make a menu file look somewhat confusing. For that reason, by default Kickshaw always saves the menu in the former format (this can be changed within the options). When saving a file, the program uses tabulators for indentations by default, but for reading the file, whether such indentations were done with spaces or tabulators is irrelevant, as is any whitespace.",
-        "A menu can contain contradictory menu attributes, as in the following example:",
-        "In this case, Kickshaw follows the example of Openbox and shows the icon attribute value from inside the root menu, while it shows the label and execute attribute values from outside the root menu.",
+        "Menu IDs may consist of empty strings. However, like any other menu ID, each can appear only once within a menu.",
+        "The following menus are equivalent and are accepted by both Openbox and Kickshaw.",
+        "In Kickshaw, a menu is always displayed as it would appear in Openbox. The second of the two examples therefore provides a closer WYSIWYG experience. The downside is that large menus may look somewhat confusing in this format. For that reason, Kickshaw saves menus in the first format by default (this can be changed in the options).",
+        "When saving a file, the program uses tabs for indentation by default. When reading a file, however, it makes no difference whether indentation was done with spaces or tabs, nor does other whitespace matter.",
+        "A menu may contain contradictory attributes, as in the following example:",
+        "In this case, Kickshaw follows Openbox’s behavior: it shows the icon attribute value from the root menu, but uses the label and execute attribute values defined outside the root menu.",
         "n/a"
     ]
     
